==> moodle_1.3.1.orig.tar.gz: moodle/lang/fr/survey.php <==
<?PHP // $Id: survey.php,v 1.12 2004/05/13 18:56:24 martignoni Exp $ 


$string['actual'] = 'Actuel';
$string['actualclass'] = 'Classe actuelle';
$string['actualstudent'] = '$a actuel';
$string['allquestions'] = 'Toutes les questions dans l\'ordre, tous les tudiants';
$string['allscales'] = 'Tous les barmes, tous les tudiants';
$string['alreadysubmitted'] = 'Vous avez dj rpondu  cette consultation';
$string['analysisof'] = 'Analyse de $a';
$string['answers'] = 'Rponses';
$string['attls1'] = 'Quand j\'value ce que dit quelqu\'un, je prte attention  la qualit de l\'argumentation, et non  la personnalit de qui la prsente.';
$string['attls10'] = 'Quand j\'analyse quelque chose, il est pour moi important de rester aussi objectif que possible.';
$string['attls10short'] = 'rester objectif';
$string['attls11'] = 'J\'essaie de penser avec les gens plutt que contre eux';
$string['attls11short'] = 'penser avec les gens';
$string['attls12'] = 'J\'ai un certain nombre de critres que j\'utilise pour valuer des arguments.';
$string['attls12short'] = 'utiliser des critres pour valuer';
$string['attls13'] = 'J\'essaie plus souvent de comprendre l\'opinion de quelqu\'un d\'autre plutt que de l\'valuer.';
$string['attls13short'] = 'essayer de comprendre';
$string['attls14'] = 'J\'essaie de montrer les faiblesses des rflexions des gens pour les aider  clarifier leur argumentation.';
$string['attls14short'] = 'montrer les faiblesses';
$string['attls15'] = 'Lors de discussions sur des sujets controverss, je tends  me mettre  la place des autres pour comprendre pourquoi ils pensent de cette faon.';
$string['attls15short'] = 'me mettre  leur place';
$string['attls16'] = 'Ma faon d\'analyser les choses pourrait s\'appeler les  mettre en jugement , car je prends le soin de considrer tous les aspects.';
$string['attls16short'] = 'mettre en jugement';
$string['attls17'] = 'Lors de la rsolution de problmes, je donne plus de poids  la logique et  la raison qu\' mes propres soucis.';
$string['attls17short'] = 'je trouve la logique plus importante';
$string['attls18'] = 'J\'arrive  comprendre les opinions diffrentes des miennes grce  mon empathie.';
$string['attls18short'] = 'comprhension par empathie';
$string['attls19'] = 'Lorsque je rencontre des gens d\'opinions qui me semblent tranges, je fais l\'effort  d\'largir  mon esprit, pour essayer de comprendre le pourquoi de ces opinions.';
$string['attls19short'] = 'faire l\'effort de s\'largir l\'esprit';
$string['attls1short'] = 'attention sur la qualit de l\'argumentation';
$string['attls2'] = 'J\'aime jouer l\'avocat du diable - en argumentant l\'oppos de ce que quelqu\'un dit.';
$string['attls20'] = 'Je prends du temps pour rechercher  ce qui ne vas pas . Par exemple je cherche dans une interprtation littraire ce qui n\'est pas suffisamment bien tay.';
$string['attls20short'] = 'qu\'est-ce qui ne  va pas ?';
$string['attls2short'] = 'jouer l\'avocat du diable';
$string['attls3'] = 'J\'aime comprendre d\'o viennent les gens, quelles expriences les ont conduits  tre comme ils sont.';
$string['attls3short'] = 'd\'o viennent les gens';
$string['attls4'] = 'La partie la plus importante de ma formation a t de comprendre les gens trs diffrents de moi.';
$string['attls4short'] = 'comprendre les personnes diffrentes';
$string['attls5'] = 'Je pense que la meilleure faon de m\'accomplir est l\'interaction avec des gens de personnalits varies.';
$string['attls5short'] = 'intragir avec des personnalits varies';
$string['attls6'] = 'J\'ai du plaisir  entendre les opinions de personnes provenant d\'autres horizons que moi ; cela m\'aide  comprendre combien de mmes choses peuvent tre comprises de diffrentes manires.';
$string['attls6short'] = 'plaisir  entendre des opinions';
$string['attls7'] = 'J\'ai l\'impression de renforcer ma propre opinion en discutant avec quelqu\'un qui n\'est pas d\'accord avec moi.';
$string['attls7short'] = 'renforcer en argumentant';
$string['attls8'] = 'Je suis toujours trs curieux de savoir pourquoi les gens croient ce qu\'ils croient.';
$string['attls8short'] = 'savoir pourquoi les gens croient';
$string['attls9'] = 'Lorsque je lis un livre, je me surprends  contrer les arguments de l\'auteur, essayant de comprendre pourquoi il a tort.';
$string['attls9short'] = 'discuter avec des auteurs';
$string['attlsintro'] = 'Le but de cette consultation est de nous aider  valuer votre tat d\'esprit vis--vis de la rflexion et de l\'apprentissage.

Il n\'y a pas de  bonne  ou de  mauvaise  rponse ; seule votre opinion nous intresse. Soyez assur que vos rponses seront traites avec le maximum de confidentialit, et qu\'elles n\'auront aucun effet sur votre note finale.';
$string['attlsm1'] = 'tat d\'esprit envers la rflexion et l\'tude';
$string['attlsm2'] = 'Apprentissage li';
$string['attlsm3'] = 'Apprentissage dtach';
$string['attlsmintro'] = 'En discussion ...';
$string['attlsname'] = 'ATTLS (20 items)';
$string['ciq1'] = ' quel moment du cours avez-vous t le plus impliqu en tant qu\'apprenant ?';
$string['ciq1short'] = 'Plus impliqu';
$string['ciq2'] = ' quel moment du cours avez-vous t le plus distant en tant qu\'apprenant ?';
$string['ciq2short'] = 'Plus distant';
$string['ciq3'] = 'Dans les forums, quelle action vous a sembl apporter le plus de soutien ou d\'aide ?';
$string['ciq3short'] = 'Moment utile';
$string['ciq4'] = 'Dans les forums, quelle action vous a sembl amener le plus d\'embarras ou de confusion ?';
$string['ciq4short'] = 'Moment embarrassant';
$string['ciq5'] = 'Quel vnement vous a le plus surpris ?';
$string['ciq5short'] = 'Moment surprenant';
$string['ciqintro'] = 'En rflchissant aux vnements rcents de ce cours, rpondez aux questions ci-dessous.';
$string['ciqname'] = 'Incidents critiques';
$string['clicktocontinue'] = 'Cliquer ici pour continuer';
$string['clicktocontinuecheck'] = 'Cliquer ici pour vrifier et continuer';
$string['colles1'] = 'mon apprentissage se concentre sur des sujets qui m\'intressent.';
$string['colles10'] = 'je demande aux autres tudiants d\'expliquer leurs ides.';
$string['colles10short'] = 'je demande des explications';
$string['colles11'] = 'les autres tudiants me demandent d\'expliquer mes ides.';
$string['colles11short'] = 'on me demande d\'expliquer';
$string['colles12'] = 'les autres tudiants rpondent  mes ides.';
$string['colles12short'] = 'les autres tudiants me rpondent';
$string['colles13'] = 'l\'enseignant stimule mes rflexions.';
$string['colles13short'] = 'l\'enseignant stimule la rflexion';
$string['colles14'] = 'l\'enseignant m\'encourage  participer.';
$string['colles14short'] = 'l\'enseignant m\'encourage';
$string['colles15'] = 'l\'enseignant donne l\'exemple en expression';
$string['colles15short'] = 'l\'enseignant donne l\'exemple en expression';
$string['colles16'] = 'l\'enseignant donne l\'exemple en auto-critique';
$string['colles16short'] = 'l\'enseignant donne l\'exemple en expression';
$string['colles17'] = 'les autres tudiants encouragent ma participation.';
$string['colles17short'] = 'les autres tudiants m\'encouragent';
$string['colles18'] = 'les autres tudiants me flicitent pour ma contribution.';
$string['colles18short'] = 'les autres tudiants me flicitent';
$string['colles19'] = 'les autres tudiants apprcient ma contribution.';
$string['colles19short'] = 'les autres tudiants m\'apprcient';
$string['colles1short'] = 'concentr sur les questions intressantes';
$string['colles2'] = 'ce que j\'apprends est important pour ma pratique professionnelle.';
$string['colles20'] = 'les autres tudiants prennent part  mes efforts pour apprendre.';
$string['colles20short'] = 'les tudiants prennent part';
$string['colles21'] = 'je comprends les messages des autres tudiants';
$string['colles21short'] = 'je comprends les autres tudiants';
$string['colles22'] = 'les autres tudiants comprennent mes messages';
$string['colles22short'] = 'les autres tudiants me comprennent';
$string['colles23'] = 'je comprends les messages de l\'enseignant ';
$string['colles23short'] = 'je comprends l\'enseignant ';
$string['colles24'] = 'l\'enseignant comprend mes messages';
$string['colles24short'] = 'l\'enseignant me comprend';
$string['colles2short'] = 'important pour ma pratique';
$string['colles3'] = 'j\'apprends comment amliorer ma pratique professionnelle.';
$string['colles3short'] = 'amliore ma pratique';
$string['colles4'] = 'ce que j\'apprends est en adquation avec ma pratique professionnelle.';
$string['colles4short'] = 'est en adquation avec ma pratique';
$string['colles5'] = 'j\'ai un regard critique sur ma faon d\'apprendre.';
$string['colles5short'] = 'j\'ai un regard critique sur mon apprentissage';
$string['colles6'] = 'j\'ai un regard critique sur mes propres ides.';
$string['colles6short'] = 'j\'ai un regard critique sur mes propres ides';
$string['colles7'] = 'j\'ai un regard critique sur les ides des autres tudiants.';
$string['colles7short'] = 'j\'ai un regard critique sur les autres tudiants';
$string['colles8'] = 'j\'ai un regard critique sur les ides dveloppes dans les documents.';
$string['colles8short'] = 'j\'ai un regard critique sur les documents';
$string['colles9'] = 'J\'explique mes ides aux autres tudiants';
$string['colles9short'] = 'J\'explique mes ides';
$string['collesaintro'] = 'L\'objet de cette consultation est de nous aider  comprendre  quel point ce cours en ligne vous a permis d\'apprendre.

Chacune des 24 affirmations ci-dessous vous interroge sur votre exprience dans ce cours.

Il n\'y a pas de rponse  juste  ou  fausse  ; nous ne nous intressons qu\' votre opinion. Soyez assur que vos rponses seront traites avec le maximum de confidentialit, et qu\'elles n\'auront aucune influence sur votre note finale.

Vos rponses soigneusement rflchies nous aideront  amliorer la faon de prsenter ce cours.

Nous vous remercions de votre collaboration.';
$string['collesaname'] = 'COLLES (rel)';
$string['collesapintro'] = 'L\'objet de cette consultation est de nous aider  comprendre  quel point ce cours en ligne vous a permis d\'apprendre.

Chacune des 24 affirmations ci-dessous vous demande de comparer votre exprience <b>idale</b> (dsire) et <b>relle</b> (vcue) dans ce cours.

Il n\'y a pas de rponse  juste  ou  fausse  ; nous ne nous intressons qu\' votre opinion. Soyez assur que vos rponses seront traites avec le maximum de confidentialit, et qu\'elles n\'auront aucune influence sur votre note finale.

Vos rponses soigneusement rflchies nous aideront  amliorer la faon de prsenter ce cours.

Nous vous remercions de votre collaboration.';
$string['collesapname'] = 'COLLES (idal et rel)';
$string['collesm1'] = 'Pertinence';
$string['collesm1short'] = 'Pertinence';
$string['collesm2'] = 'Pense rflexive';
$string['collesm2short'] = 'Pense rflexive';
$string['collesm3'] = 'Interactivit';
$string['collesm3short'] = 'Interactivit';
$string['collesm4'] = 'Assistance de l\'enseignant';
$string['collesm4short'] = 'Assistance de l\'enseignant ';
$string['collesm5'] = 'Assistance des pairs';
$string['collesm5short'] = 'Assistance des pairs';
$string['collesm6'] = 'Interprtation';
$string['collesm6short'] = 'Interprtation';
$string['collesmintro'] = 'Dans ce cours en ligne ...';
$string['collespintro'] = 'L\'objet de cette consultation est de nous aider  comprendre  quel point ce cours en ligne vous a permis d\'apprendre.

Chacune des 24 affirmations ci-dessous vous interroge sur votre exprience <b>idale</b> (dsire) dans ce cours.

Il n\'y a pas de rponse  juste  ou  fausse  ; nous ne nous intressons qu\' votre opinion. Soyez assur que vos rponses seront traites avec le maximum de confidentialit, et qu\'elles n\'auront aucune influence sur votre note finale.

Vos rponses soigneusement rflchies nous aideront  amliorer la faon de prsenter ce cours.

Nous vous remercions de votre collaboration.';
$string['collespname'] = 'COLLES (idal)';
$string['done'] = 'Termin';
$string['download'] = 'Tlcharger';
$string['downloadexcel'] = 'Tlcharger les donnes en format Excel';
$string['downloadinfo'] = 'Il vous est possible de tlcharger l\'ensemble des donnes brutes de ce sondage dans un format utilisable par un tableur, SPSS ou d\'autres programmes.';
$string['downloadtext'] = 'Tlcharger les donnes dans un format texte';
$string['editingasurvey'] = 'Modifier une consultation';
$string['guestsnotallowed'] = 'Les utilisateurs anonymes ne peuvent pas participer  des consultations';
$string['helpsurveys'] = 'Aide sur les diffrents types de consultation';
$string['howlong'] = 'Combien de temps avez-vous mis pour rpondre  cette consultation ?';
$string['howlongoptions'] = 'Moins d\'1 min,1-2 min,2-3 min,3-4 min,4-5 min,5-10 min,plus de 10 min';
$string['ifoundthat'] = 'J\'ai trouv que';
$string['introtext'] = 'Texte d\'introduction';
$string['ipreferthat'] = 'J\'aime mieux quand';
$string['modulename'] = 'Consultation pdagogique';
$string['modulenameplural'] = 'Consultations pdagogiques';
$string['name'] = 'Nom';
$string['newsurveyresponses'] = 'Nouvelles rponses  une consultation';
$string['nobodyyet'] = 'Personne n\'a encore rpondu  cette consultation';
$string['notdone'] = 'Pas encore rpondu';
$string['notes'] = 'Votre analyse et vos remarques personnelles';
$string['othercomments'] = 'Avez-vous d\'autres commentaires  faire ?';
$string['peoplecompleted'] = '$a autres personnes ont pour l\'instant rpondu  cette consultation';
$string['preferred'] = 'Prfr';
$string['preferredclass'] = 'Classe prfre';
$string['preferredstudent'] = '$a prfr';
$string['question'] = 'Question';
$string['questions'] = 'Questions';
$string['questionsnotanswered'] = 'Certaines questions  choix multiples n\'ont pas reu de rponse.';
$string['report'] = 'Rapport des consultations';
$string['savednotes'] = 'Vos notes ont t enregistres';
$string['scaleagree5'] = 'Pas du tout d\'accord,Pas tout  fait d\'accord,Neutre,Assez d\'accord,Tout  fait d\'accord';
$string['scales'] = 'Barmes';
$string['scaletimes5'] = 'Presque jamais,Rarement,Parfois,Souvent,Presque toujours';
$string['seemoredetail'] = 'Cliquer ici pour avoir plus de dtail';
$string['selectedquestions'] = 'Question choisies dans un barme, tous les tudiants';
$string['summary'] = 'Rsum';
$string['surveycompleted'] = 'Vous avez compltement rpondu  cette consultation. Le graphique ci-dessous montre un rsum de vos rsultats compars aux moyennes de la classe.';
$string['surveyname'] = 'Nom de la consultation';
$string['surveysaved'] = 'Consultation enregistre';
$string['surveytype'] = 'Type de consultation';
$string['thanksforanswers'] = 'Merci d\'avoir rpondu  cette consultation, $a';
$string['time'] = 'Temps';
$string['viewsurveyresponses'] = 'Afficher les rponses  la consultation $a';

?>

==> moodle_1.4.4.dfsg.1.orig.tar.gz: moodle/lang/fr/survey.php <==
<?php // $Id$ 

$string['actual'] = 'Actuel';
$string['actualclass'] = 'Classe actuelle';
$string['actualstudent'] = '$a actuel';
$string['allquestions'] = 'Toutes les questions dans l\'ordre, tous les tudiants';
$string['allscales'] = 'Tous les barmes, tous les tudiants';
$string['alreadysubmitted'] = 'Vous avez dj rpondu  cette consultation';
$string['analysisof'] = 'Analyse de $a';
$string['answers'] = 'Rponses';
$string['attls1'] = 'Quand j\'value ce que dit quelqu\'un, je prte attention  la qualit de l\'argumentation, et non  la personnalit de qui la prsente.';
$string['attls10'] = 'Quand j\'analyse quelque chose, il est pour moi important de rester aussi objectif que possible.';
$string['attls10short'] = 'rester objectif';
$string['attls11'] = 'J\'essaie de penser avec les gens plutt que contre eux';
$string['attls11short'] = 'penser avec les gens';
$string['attls12'] = 'J\'ai un certain nombre de critres que j\'utilise pour valuer des arguments.';
$string['attls12short'] = 'utiliser des critres pour valuer';
$string['attls13'] = 'J\'essaie plus souvent de comprendre l\'opinion de quelqu\'un d\'autre plutt que de l\'valuer.';
$string['attls13short'] = 'essayer de comprendre';
$string['attls14'] = 'J\'essaie de montrer les faiblesses des rflexions des gens pour les aider  clarifier leur argumentation.';
$string['attls14short'] = 'montrer les faiblesses';
$string['attls15'] = 'Lors de discussions sur des sujets controverss, je tends  me mettre  la place des autres pour comprendre pourquoi ils pensent de cette faon.';
$string['attls15short'] = 'me mettre  leur place';
$string['attls16'] = 'Ma faon d\'analyser les choses pourrait s\'appeler les  mettre en jugement , car je prends le soin de considrer tous les aspects.';
$string['attls16short'] = 'mettre en jugement';
$string['attls17'] = 'Lors de la rsolution de problmes, je donne plus de poids  la logique et  la raison qu\' mes propres soucis.';
$string['attls17short'] = 'je trouve la logique plus importante';
$string['attls18'] = 'J\'arrive  comprendre les opinions diffrentes des miennes grce  mon empathie.';
$string['attls18short'] = 'comprhension par empathie';
$string['attls19'] = 'Lorsque je rencontre des gens d\'opinions qui me semblent tranges, je fais l\'effort  d\'largir  mon esprit, pour essayer de comprendre le pourquoi de ces opinions.';
$string['attls19short'] = 'faire l\'effort de s\'largir l\'esprit';
$string['attls1short'] = 'attention sur la qualit de l\'argumentation';
$string['attls2'] = 'J\'aime jouer l\'avocat du diable - en argumentant l\'oppos de ce que quelqu\'un dit.';
$string['attls20'] = 'Je prends du temps pour rechercher  ce qui ne vas pas . Par exemple je cherche dans une interprtation littraire ce qui n\'est pas suffisamment bien tay.';
$string['attls20short'] = 'qu\'est-ce qui ne  va pas ?';
$string['attls2short'] = 'jouer l\'avocat du diable';
$string['attls3'] = 'J\'aime comprendre d\'o viennent les gens, quelles expriences les ont conduits  tre comme ils sont.';
$string['attls3short'] = 'd\'o viennent les gens';
$string['attls4'] = 'La partie la plus importante de ma formation a t de comprendre les gens trs diffrents de moi.';
$string['attls4short'] = 'comprendre les personnes diffrentes';
$string['attls5'] = 'Je pense que la meilleure faon de m\'accomplir est l\'interaction avec des gens de personnalits varies.';
$string['attls5short'] = 'intragir avec des personnalits varies';
$string['attls6'] = 'J\'ai du plaisir  entendre les opinions de personnes provenant d\'autres horizons que moi ; cela m\'aide  comprendre combien de mmes choses peuvent tre comprises de diffrentes manires.';
$string['attls6short'] = 'plaisir  entendre des opinions';
$string['attls7'] = 'J\'ai l\'impression de renforcer ma propre opinion en discutant avec quelqu\'un qui n\'est pas d\'accord avec moi.';
$string['attls7short'] = 'renforcer en argumentant';
$string['attls8'] = 'Je suis toujours trs curieux de savoir pourquoi les gens croient ce qu\'ils croient.';
$string['attls8short'] = 'savoir pourquoi les gens croient';
$string['attls9'] = 'Lorsque je lis un livre, je me surprends  contrer les arguments de l\'auteur, essayant de comprendre pourquoi il a tort.';
$string['attls9short'] = 'discuter avec des auteurs';
$string['attlsintro'] = 'Le but de cette consultation est de nous aider  valuer votre tat d\'esprit vis--vis de la rflexion et de l\'apprentissage.

Il n\'y a pas de  bonne  ou de  mauvaise  rponse ; seule votre opinion nous intresse. Soyez assur que vos rponses seront traites avec le maximum de confidentialit, et qu\'elles n\'auront aucun effet sur votre note finale.';
$string['attlsm1'] = 'tat d\'esprit envers la rflexion et l\'tude';
$string['attlsm2'] = 'Apprentissage li';
$string['attlsm3'] = 'Apprentissage dtach';
$string['attlsmintro'] = 'En discussion ...';
$string['attlsname'] = 'ATTLS (20 items)';
$string['ciq1'] = ' quel moment du cours avez-vous t le plus impliqu en tant qu\'apprenant ?';
$string['ciq1short'] = 'Plus impliqu';
$string['ciq2'] = ' quel moment du cours avez-vous t le plus distant en tant qu\'apprenant ?';
$string['ciq2short'] = 'Plus distant';
$string['ciq3'] = 'Dans les forums, quelle action vous a sembl apporter le plus de soutien ou d\'aide ?';
$string['ciq3short'] = 'Moment utile';
$string['ciq4'] = 'Dans les forums, quelle action vous a sembl amener le plus d\'embarras ou de confusion ?';
$string['ciq4short'] = 'Moment embarrassant';
$string['ciq5'] = 'Quel vnement vous a le plus surpris ?';
$string['ciq5short'] = 'Moment surprenant';
$string['ciqintro'] = 'En rflchissant aux vnements rcents de ce cours, rpondez aux questions ci-dessous.';
$string['ciqname'] = 'Incidents critiques';
$string['clicktocontinue'] = 'Cliquer ici pour continuer';
$string['clicktocontinuecheck'] = 'Cliquer ici pour vrifier et continuer';
$string['colles1'] = 'mon apprentissage se concentre sur des sujets qui m\'intressent.';
$string['colles10'] = 'je demande aux autres tudiants d\'expliquer leurs ides.';
$string['colles10short'] = 'je demande des explications';
$string['colles11'] = 'les autres tudiants me demandent d\'expliquer mes ides.';
$string['colles11short'] = 'on me demande d\'expliquer';
$string['colles12'] = 'les autres tudiants rpondent  mes ides.';
$string['colles12short'] = 'les autres tudiants me rpondent';
$string['colles13'] = 'l\'enseignant stimule mes rflexions.';
$string['colles13short'] = 'l\'enseignant stimule la rflexion';
$string['colles14'] = 'l\'enseignant m\'encourage  participer.';
$string['colles14short'] = 'l\'enseignant m\'encourage';
$string['colles15'] = 'l\'enseignant donne l\'exemple en expression';
$string['colles15short'] = 'l\'enseignant donne l\'exemple en expression';
$string['colles16'] = 'l\'enseignant donne l\'exemple en auto-critique';
$string['colles16short'] = 'l\'enseignant donne l\'exemple en expression';
$string['colles17'] = 'les autres tudiants encouragent ma participation.';
$string['colles17short'] = 'les autres tudiants m\'encouragent';
$string['colles18'] = 'les autres tudiants me flicitent pour ma contribution.';
$string['colles18short'] = 'les autres tudiants me flicitent';
$string['colles19'] = 'les autres tudiants apprcient ma contribution.';
$string['colles19short'] = 'les autres tudiants m\'apprcient';
$string['colles1short'] = 'concentr sur les questions intressantes';
$string['colles2'] = 'ce que j\'apprends est important pour ma pratique professionnelle.';
$string['colles20'] = 'les autres tudiants prennent part  mes efforts pour apprendre.';
$string['colles20short'] = 'les tudiants prennent part';
$string['colles21'] = 'je comprends les messages des autres tudiants';
$string['colles21short'] = 'je comprends les autres tudiants';
$string['colles22'] = 'les autres tudiants comprennent mes messages';
$string['colles22short'] = 'les autres tudiants me comprennent';
$string['colles23'] = 'je comprends les messages de l\'enseignant ';
$string['colles23short'] = 'je comprends l\'enseignant ';
$string['colles24'] = 'l\'enseignant comprend mes messages';
$string['colles24short'] = 'l\'enseignant me comprend';
$string['colles2short'] = 'important pour ma pratique';
$string['colles3'] = 'j\'apprends comment amliorer ma pratique professionnelle.';
$string['colles3short'] = 'amliore ma pratique';
$string['colles4'] = 'ce que j\'apprends est en adquation avec ma pratique professionnelle.';
$string['colles4short'] = 'est en adquation avec ma pratique';
$string['colles5'] = 'j\'ai un regard critique sur ma faon d\'apprendre.';
$string['colles5short'] = 'j\'ai un regard critique sur mon apprentissage';
$string['colles6'] = 'j\'ai un regard critique sur mes propres ides.';
$string['colles6short'] = 'j\'ai un regard critique sur mes propres ides';
$string['colles7'] = 'j\'ai un regard critique sur les ides des autres tudiants.';
$string['colles7short'] = 'j\'ai un regard critique sur les autres tudiants';
$string['colles8'] = 'j\'ai un regard critique sur les ides dveloppes dans les documents.';
$string['colles8short'] = 'j\'ai un regard critique sur les documents';
$string['colles9'] = 'J\'explique mes ides aux autres tudiants';
$string['colles9short'] = 'J\'explique mes ides';
$string['collesaintro'] = 'L\'objet de cette consultation est de nous aider  comprendre  quel point ce cours en ligne vous a permis d\'apprendre.

Chacune des 24 affirmations ci-dessous vous interroge sur votre exprience dans ce cours.

Il n\'y a pas de rponse  juste  ou  fausse  ; nous ne nous intressons qu\' votre opinion. Soyez assur que vos rponses seront traites avec le maximum de confidentialit, et qu\'elles n\'auront aucune influence sur votre note finale.

Vos rponses soigneusement rflchies nous aideront  amliorer la faon de prsenter ce cours.

Nous vous remercions de votre collaboration.';
$string['collesaname'] = 'COLLES (rel)';
$string['collesapintro'] = 'L\'objet de cette consultation est de nous aider  comprendre  quel point ce cours en ligne vous a permis d\'apprendre.

Chacune des 24 affirmations ci-dessous vous demande de comparer votre exprience <strong>idale</strong> (dsire) et <strong>relle</strong> (vcue) dans ce cours.

Il n\'y a pas de rponse  juste  ou  fausse  ; nous ne nous intressons qu\' votre opinion. Soyez assur que vos rponses seront traites avec le maximum de confidentialit, et qu\'elles n\'auront aucune influence sur votre note finale.

Vos rponses soigneusement rflchies nous aideront  amliorer la faon de prsenter ce cours.

Nous vous remercions de votre collaboration.';
$string['collesapname'] = 'COLLES (idal et rel)';
$string['collesm1'] = 'Pertinence';
$string['collesm1short'] = 'Pertinence';
$string['collesm2'] = 'Pense rflexive';
$string['collesm2short'] = 'Pense rflexive';
$string['collesm3'] = 'Interactivit';
$string['collesm3short'] = 'Interactivit';
$string['collesm4'] = 'Assistance de l\'enseignant';
$string['collesm4short'] = 'Assistance de l\'enseignant ';
$string['collesm5'] = 'Assistance des pairs';
$string['collesm5short'] = 'Assistance des pairs';
$string['collesm6'] = 'Interprtation';
$string['collesm6short'] = 'Interprtation';
$string['collesmintro'] = 'Dans ce cours en ligne ...';
$string['collespintro'] = 'L\'objet de cette consultation est de nous aider  comprendre  quel point ce cours en ligne vous a permis d\'apprendre.

Chacune des 24 affirmations ci-dessous vous interroge sur votre exprience <strong>idale</strong> (dsire) dans ce cours.

Il n\'y a pas de rponse  juste  ou  fausse  ; nous ne nous intressons qu\' votre opinion. Soyez assur que vos rponses seront traites avec le maximum de confidentialit, et qu\'elles n\'auront aucune influence sur votre note finale.

Vos rponses soigneusement rflchies nous aideront  amliorer la faon de prsenter ce cours.

Nous vous remercions de votre collaboration.';
$string['collespname'] = 'COLLES (idal)';
$string['done'] = 'Termin';
$string['download'] = 'Tlcharger';
$string['downloadexcel'] = 'Tlcharger les donnes en format Excel';
$string['downloadinfo'] = 'Il vous est possible de tlcharger l\'ensemble des donnes brutes de ce sondage dans un format utilisable par un tableur, SPSS ou d\'autres programmes.';
$string['downloadtext'] = 'Tlcharger les donnes dans un format texte';
$string['editingasurvey'] = 'Modifier une consultation';
$string['guestsnotallowed'] = 'Les utilisateurs anonymes ne peuvent pas participer  des consultations';
$string['helpsurveys'] = 'Aide sur les diffrents types de consultation';
$string['howlong'] = 'Combien de temps avez-vous mis pour rpondre  cette consultation ?';
$string['howlongoptions'] = 'Moins d\'1 min,1-2 min,2-3 min,3-4 min,4-5 min,5-10 min,Plus de 10 min';
$string['ifoundthat'] = 'J\'ai trouv que';
$string['introtext'] = 'Texte d\'introduction';
$string['ipreferthat'] = 'J\'aime mieux quand';
$string['modulename'] = 'Consultation';
$string['modulenameplural'] = 'Consultations';
$string['name'] = 'Nom';
$string['newsurveyresponses'] = 'Nouvelles rponses  une consultation';
$string['nobodyyet'] = 'Personne n\'a encore rpondu  cette consultation';
$string['notdone'] = 'Pas encore rpondu';
$string['notes'] = 'Votre analyse et vos remarques personnelles';
$string['othercomments'] = 'Avez-vous d\'autres commentaires  faire ?';
$string['peoplecompleted'] = '$a autres personnes ont pour l\'instant rpondu  cette consultation';
$string['preferred'] = 'Prfr';
$string['preferredclass'] = 'Classe prfre';
$string['preferredstudent'] = '$a prfr';
$string['question'] = 'Question';
$string['questions'] = 'Questions';
$string['questionsnotanswered'] = 'Certaines questions  choix multiples n\'ont pas reu de rponse.';
$string['report'] = 'Rapport des consultations';
$string['savednotes'] = 'Vos notes ont t enregistres';
$string['scaleagree5'] = 'Pas du tout d\'accord,Pas tout  fait d\'accord,Neutre,Assez d\'accord,Tout  fait d\'accord';
$string['scales'] = 'Barmes';
$string['scaletimes5'] = 'Presque jamais,Rarement,Parfois,Souvent,Presque toujours';
$string['seemoredetail'] = 'Cliquer ici pour avoir plus de dtail';
$string['selectedquestions'] = 'Questions choisies dans un barme, tous les tudiants';
$string['summary'] = 'Rsum';
$string['surveycompleted'] = 'Vous avez compltement rpondu  cette consultation. Le graphique ci-dessous montre un rsum de vos rsultats compars aux moyennes de la classe.';
$string['surveyname'] = 'Nom de la consultation';
$string['surveysaved'] = 'Consultation enregistre';
$string['surveytype'] = 'Type de consultation';
$string['thanksforanswers'] = 'Merci d\'avoir rpondu  cette consultation, $a';
$string['time'] = 'Temps';
$string['viewsurveyresponses'] = 'Afficher les $a rponses  la consultation';

?>
